# Fibonacci Demo

You wake on `fibonacci:poke`.

What is the next item in the Fibonacci sequence?

If this is the first time, reply with `0`.
Otherwise, look back at the prior conversation in this session and continue the
sequence from there.

Reply with only the next Fibonacci number.
Do not ask questions.
Do not use tools, write files, or send events.
